Write a table to a database with column and table constraints
1 2 |
db |
A DBI::DBIConnection object. |
df |
A data frame object. |
tbl_name |
Name of the database. |
p_key |
Column to be constrained as |
u_keys |
Character vector with columns to be constrained as |
nn_keys |
Character vector with columns to be constrained as |
no_null |
Boolean. If |
f_keys |
Lists of foreign key declarations. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.